﻿using System;
using System.IO;
using Hardcodet.TempStorage;

namespace ConsoleApplication1
{
  /// <summary>
  /// A factory implementation that returns
  /// <see cref="TempFileStream"/> instances which
  /// use local temporary files.
  /// </summary>
  public class TempFileStreamFactory : ITempStreamFactory
  {
    public string RootFolder { get; set; }

    public TempFileStreamFactory(string rootFolder)
    {
      if (!Directory.Exists(rootFolder)) Directory.CreateDirectory(rootFolder);
      RootFolder = rootFolder;
    }

    /// <summary>
    /// Gets a <see cref="Stream"/> that automatically cleans up
    /// after itself.
    /// </summary>
    /// <returns>A stream that allows to write and read temporary
    /// data.</returns>
    public Stream CreateTempStream()
    {
      //construct a temporary file path
      string path = Path.Combine(RootFolder, Guid.NewGuid() + ".tmp");
      var tempFile = new FileInfo(path);

      return new TempFileStream(tempFile);
    }

  }
}
