﻿using System;
using System.IO;
using System.IO.IsolatedStorage;
using Hardcodet.TempStorage;

namespace SilverlightApplication1
{
  /// <summary>
  /// Provides temporary file management for Silverlight
  /// applications based on isolated storage.
  /// </summary>
  public class IsolatedStorageTempStream : TempStream
  {
    /// <summary>
    /// The name of the tempoarary file that is being created
    /// in isolated storage.
    /// </summary>
    public string TempFileName { get; private set; }

       

    public IsolatedStorageTempStream()
    {
      //use a GUID as the temporary file name
      TempFileName = String.Format("{0}.tmp", Guid.NewGuid());
    }


    /// <summary>
    /// Creates the underlying stream. This method is being invoked on the first
    /// request of the <see cref="TempStream.DecoratedStream"/> property.
    /// </summary>
    /// <returns>A temporary stream that supports seeking.</returns>
    protected override Stream CreateTempDataStream()
    {
      IsolatedStorageFile store = IsolatedStorageFile.GetUserStoreForApplication();
      return store.CreateFile(TempFileName);
    }


    /// <summary>
    /// When invoked (which happens during disposal), implementing classes
    /// should clean up temporary resources. Note that at the time this
    /// method is being invoked, the <see cref="TempStream.DecoratedStream"/> has
    /// already been disposed.
    /// </summary>
    protected override void DiscardTempResources()
    {
      IsolatedStorageFile store = IsolatedStorageFile.GetUserStoreForApplication();
      store.DeleteFile(TempFileName);
    }
  }
}
