﻿using System.IO;
using System.IO.IsolatedStorage;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using Hardcodet.TempStorage;

namespace SilverlightApplication1
{
  public partial class MainPage : UserControl
  {
    public ITempStreamFactory StreamFactory { get; set; }

    public MainPage()
    {
      InitializeComponent();
      StreamFactory = new TempStreamFactory();
    }



    private void CreateAndDeleteTempFile(object sender, RoutedEventArgs e)
    {
      //get a temp stream
      using(Stream stream = StreamFactory.CreateTempStream())
      {
        //write some data
        var data = Encoding.UTF8.GetBytes("hello world");
        stream.Write(data, 0, data.Length);

        ShowFileList("Acquiring a temporary stream should have created a file in Isolated Storage. As soon as you click OK, the temp stream will be disposed.");
      }

      ShowFileList("As the temporary stream was disposed, the file should have been removed from Isolated Storage.");
    }


    private static void ShowFileList(string message)
    {
      var store = IsolatedStorageFile.GetUserStoreForApplication();
      var fileNames = store.GetFileNames();


      var builder = new StringBuilder(message);
      builder.AppendLine().AppendLine().AppendLine("--");
      builder.Append(fileNames.Length).AppendLine(" files in Isolated Storage\n");
      
      foreach (string fileName in fileNames)
      {
        builder.AppendLine(fileName);
      }

      MessageBox.Show(builder.ToString());
    }
  }
}
